/*
 * unix.c
 * Copyright (c) A.J. van Os
 *
 * Description:
 * Unix approximations of RISC-OS functions
 */

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include "antiword.h"


/*
 * werr - write an error message and exit if needed
 */
void
werr(int iFatal, const char *szFormat, ...)
{
	va_list tArg;

	va_start(tArg, szFormat);
	vfprintf(stderr, szFormat, tArg);
	va_end(tArg);
	fprintf(stderr, "\n");
	if (iFatal != 0) {
		exit(iFatal);
	}
} /* end of werr */

void
visdelay_begin(void)
{
} /* end of visdelay_begin */

void
visdelay_end(void)
{
} /* end of visdelay_end */

void
vCloseFont()
{
} /* end of vCloseFont */

draw_fontref
tOpenFont(unsigned char ucWordFontNumber,
		unsigned char ucFontstyle, unsigned char ucWordFontsize)
{
	return 0;	/* Use default/current font */
} /* end of tOpenFont */

draw_fontref
tOpenTableFont(unsigned char ucWordFontsize)
{
	return 0;	/* Use default/current font */
} /* end of tOpenTableFont */

void
vAddFonts2Diagram(diagram_type *pDiag)
{
} /* end of vAddFonts2Diagram */

void
vSubstring2Diagram(diagram_type *pDiag,
		char *szString, int iStringLength, int iStringWidth,
		int iColour, draw_fontref tFontRef, int iFontsize)
{
	int	iLen;

	fail(pDiag == NULL || szString == NULL);
	fail(pDiag->pFile == NULL);
	fail(pDiag->iXleft < 0);
	fail(iStringLength != strlen(szString));
	fail(iFontsize < MIN_FONT_SIZE || iFontsize > MAX_FONT_SIZE);

	if (szString[0] == '\0' || iStringLength <= 0) {
		return;
	}

	iLen = fprintf(pDiag->pFile, "%.*s", iStringLength, szString);
	if (iLen < 0) {
		iLen = 0;
	}
	pDiag->iXleft += iLen;
} /* end of vSubstring2Diagram */

/*
 * vSetLeftIndentation - set the left indentation of the given diagram
 */
void
vSetLeftIndentation(diagram_type *pDiag, int iLeftIndentation)
{
	int	iX, iCount;

	fail(pDiag == NULL || iLeftIndentation < 0);
	fail(pDiag->pFile == NULL);

	iX = iMilliPoints2Char(iLeftIndentation);
	if (iX > pDiag->iXleft)  {
  		for (iCount = pDiag->iXleft; iCount < iX; iCount++) {
			fprintf(pDiag->pFile, "%c", FILLER_CHAR);
		}
		pDiag->iXleft = iX;
	}
} /* end of vSetLeftIndentation */

/*
 * Start on a new line plus an empty line
 */
void
vEndOfParagraph2Diagram(diagram_type *pDiag,
			draw_fontref tFontRef, unsigned char ucFontSize)
{
	fail(pDiag == NULL);
	fail(pDiag->pFile == NULL);
	fail((int)ucFontSize < MIN_FONT_SIZE || (int)ucFontSize > MAX_FONT_SIZE);

	if (pDiag->iXleft > 0) {
		/* To the start of the line */
		fprintf(pDiag->pFile, "\n");
	}
	/* Empty line */
	fprintf(pDiag->pFile, "\n");
	pDiag->iXleft = 0;
} /* end of vEndOfParagraph2Diagram */

/*
 *
 */
void
vEmptyLine2Diagram(diagram_type *pDiag,
			draw_fontref tFontRef, unsigned char ucFontSize)
{
	vEndOfParagraph2Diagram(pDiag, tFontRef, ucFontSize);
} /* end of vEmptyLine2Diagram */

/*
 * iComputeStringWidth - compute the string width
 *
 * Returns the string width in millipoints
 */
int
iComputeStringWidth(char *szString, int iStringLength)
{
	fail(szString == NULL || iStringLength < 0);

	return iChar2MilliPoints(iStringLength);
} /* end of iComputeStringWidth */
