/*
 * xmalloc.c
 * Copyright (C) 1998 A.J. van Os
 *
 * Description:
 * Extended malloc and friends
 */

#include <stdlib.h>
#include "antiword.h"

static char *szWarning = "Memory allocation failed, unable to continue";


/*
 * xmalloc - Allocates dynamic memory
 *
 * See malloc(3), but unlike malloc(3) xmalloc does not return in case
 * of error.
 */
void *
xmalloc(size_t tSize)
{
	void	*pvTmp;

	pvTmp = malloc(tSize);
	if (pvTmp == NULL) {
		werr(1, szWarning);
	}
	return pvTmp;
} /* end of xmalloc */

/*
 * xrealloc - Changes the size of a memory object
 *
 * See realloc(3), but unlike realloc(3) xrealloc does not return in case
 * of error.
 */
void *
xrealloc(void *pvArg, size_t tSize)
{
	void	*pvTmp;

	pvTmp = realloc(pvArg, tSize);
	if (pvTmp == NULL) {
		werr(1, szWarning);
	}
	return pvTmp;
} /* end of xrealloc */

/*
 * xfree - Deallocates dynamic memory
 *
 * See free(3).
 */
void
xfree(void *pvArg)
{
	if (pvArg != NULL) {
		free(pvArg);
	}
} /* end of xfree */
